@@ -1,28 +1,13 @@
-/*
- * Copyright (C) 2017 ~ 2018 Deepin Technology Co., Ltd.
- *
- * Author:     sbw <sbw@sbw.so>
- *
- * Maintainer: sbw <sbw@sbw.so>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2022 - 2023 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #ifndef PACKAGESMANAGER_H
 #define PACKAGESMANAGER_H
 
+#include "utils/package_defines.h"
 #include "utils/result.h"
+#include "model/dependgraph.h"
 
 #include <QApt/Backend>
 #include <QApt/DebFile>
@@ -43,19 +28,16 @@ class DebListModel;
 class DealDependThread;
 class AddPackageThread;
 
+namespace Deb {
+class DebPackage;
+}; // namespace Deb
+
 /**
  * @brief init_backend 初始化后端
  * @return 初始化完成的后端指针
  */
 Backend *init_backend();
 
-struct DependInfo {
-    QString packageName; //依赖的包名称
-    QString version; //依赖的包的版本
-};
-
-typedef QPair<QList<DependInfo>, QList<DependInfo>> DependsPair;
-
 class PackagesManager : public QObject
 {
     Q_OBJECT
@@ -82,8 +64,8 @@ public:
      * @param multiArchType 多架构的类型
      * @return
      */
-    static QString resolvMultiArchAnnotation(const QString &annotation, const QString &debArch,
-                                      const int multiArchType = InvalidMultiArchType);
+    static QString
+    resolvMultiArchAnnotation(const QString &annotation, const QString &debArch, const int multiArchType = InvalidMultiArchType);
 
     /**
      * @brief dependencyVersionMatch 判断当前依赖版本是否匹配
@@ -94,10 +76,27 @@ public:
     static bool dependencyVersionMatch(const int result, const RelationType relation);
 
     /**
-     * @brief selectedIndexRow 当前选择安装包列表的行
-     * @param row 行号
+     * @brief searchPackageInstallInfo 查找指定包安装状态
+     * @param package_path 路径
      */
-    void selectedIndexRow(int row);
+    Pkg::PackageInstallStatus checkInstallStatus(const QString &package_path);
+    /**
+     * @brief searchPackageInstallInfo 查找指定包依赖
+     * @param package_path 包名字
+     */
+    PackageDependsStatus checkDependsStatus(const QString &package_path);
+    /**
+     * @brief searchPackageInstallInfo 查找指定包信息
+     * @param package_path 包名字
+     */
+    QStringList getPackageInfo(const QString &package_path);
+    /**
+     * @brief checkPackageValid 检查包有效性
+     * @param package_path 包名字
+     */
+    QString checkPackageValid(const QStringList &package_path);
+
+    QStringList removePackages(const QByteArray &md5) const;
 
 public slots:
     /**
@@ -106,38 +105,24 @@ public slots:
      * @param iIndex    wine应用的下标
      * @param dependName    wine依赖错误的依赖名称
      */
-    void slotDealDependResult(int iAuthRes, int iIndex, QString dependName);
+    void slotDealDependResult(int iAuthRes, int iIndex, const QString &dependName);
 
-//// 依赖下载相关信号
+    //// 依赖下载相关信号
 signals:
     /**
      * @brief DependResult 处理wine依赖下载结果
      */
-    void signalDependResult(int, int, QString);
+    void signalDependResult(int, int, const QString &);
 
     /**
      * @brief enableCloseButton 设置关闭按钮是否可用的信号
      */
     void signalEnableCloseButton(bool);
 
-////添加包相关信号
+    ////添加包相关信号
 signals:
-    /**
-     * @brief invalidPackage 无效包的信号
-     */
-    void signalInvalidPackage();
-
-    /**
-     * @brief notLocalPackage 包不在本地的信号
-     *
-     * 包不在本地无法安装
-     */
-    void signalNotLocalPackage();
-
-    /**
-     * @brief packageAlreadyExists 包重复添加的信号
-     */
-    void signalPackageAlreadyExists();
+    // Manange package insert failed reason.
+    void signalAppendFailMessage(Pkg::AppendFailReason reason, Pkg::PackageType type = Pkg::Deb);
 
     /**
      * @brief appendStart 批量安装开始添加包的信号
@@ -148,50 +133,23 @@ signals:
      * @brief appendFinished 批量安装添加包结束的信号
      * @param packageMd5List 添加后的md5列表
      */
-    void signalAppendFinished(QList<QByteArray> packageMd5List);
+    void signalAppendFinished(const QList<QByteArray> &packageMd5List);
 
     /**
      * @brief packageMd5Changed 添加完成之后更新MD5的列表
      * @param packageMd5List 当前的MD5列表
      */
-    void signalPackageMd5Changed(QList<QByteArray> packageMd5List);
+    void signalPackageMd5Changed(const QList<QByteArray> &packageMd5List);
 
-//// 界面刷新相关信号
+    //// 界面刷新相关信号
 signals:
     /**
-     * @brief single2MultiPage 单包安装刷新为批量安装的信号
+       @brief signalPacakgeCountChanged notify pacakge append or remove.
      */
-    void signalSingle2MultiPage();
+    void signalPackageCountChanged(int count);
 
-    /**
-     * @brief refreshSinglePage 刷新单包安装界面的信号
-     */
-    void signalRefreshSinglePage();
-
-    /**
-     * @brief refreshMultiPage 刷新批量安装界面的信号
-     */
-    void signalRefreshMultiPage();
-
-    /**
-     * @brief refreshFileChoosePage 刷新首页
-     */
-    void signalRefreshFileChoosePage();
-
-    /**
-     * @brief signalSingleDependPackages
-     * @param breakPackages
-     */
-    void signalSingleDependPackages(DependsPair dependPackages, bool installWineDepends);
-
-    /**
-     * @brief signalMultDependPackages
-     * @param breakPackages
-     */
-    void signalMultDependPackages(DependsPair dependPackages, bool installWineDepends);
     //// 后端状态相关函数
 public:
-
     /**
      * @brief isBackendReady 判断安装程序后端是否加载完成
      * @return 安装程序后端加载的结果
@@ -201,18 +159,8 @@ public:
      */
     bool isBackendReady();
 
-    /**
-     * @brief backend 获取后端指针
-     * @return  后端的指针
-     */
-    QApt::Backend *backend() const
-    {
-        return m_backendFuture.result();
-    }
-
-//// 包状态相关函数
+    //// 包状态相关函数
 public:
-
     /**
      * @brief package   获取指定下标的包的路径
      * @param index  下标
@@ -229,7 +177,7 @@ public:
      * true: 不符合当前系统架构的要求
      */
     bool isArchError(const int idx);
-
+    bool isArchErrorQstring(const QString &package_name);
 
     /**
      * @brief packageInstallStatus 获取指定index的包的安装状态
@@ -238,7 +186,6 @@ public:
      */
     int packageInstallStatus(const int index);
 
-
     /**
      * @brief packageInstalledVersion 获取指定下标的包的安装版本
      * @param index 下标
@@ -246,7 +193,6 @@ public:
      */
     const QString packageInstalledVersion(const int index);
 
-
     /**
      * @brief packageConflictStat 获取指定包的冲突状态
      * @param index 下标
@@ -254,7 +200,6 @@ public:
      */
     const ConflictResult packageConflictStat(const int index);
 
-
     /**
      * @brief packageAvailableDepends 获取指定包的可用的依赖
      * @param index 下标
@@ -262,6 +207,8 @@ public:
      */
     const QStringList packageAvailableDepends(const int index);
 
+    QStringList debFileAvailableDepends(const QString &filePath);
+
     /**
      * @brief getPackageDependsStatus 获取指定包的依赖的状态
      * @param index 下标
@@ -292,7 +239,7 @@ public:
      */
     const QStringList packageReverseDependsList(const QString &packageName, const QString &sysArch);
 
-//// 添加删除相关函数
+    //// 添加删除相关函数
 public:
     /**
      * @brief appendPackage 添加包到程序中
@@ -305,9 +252,9 @@ public:
      * @param index 要删除的包的下标
      * @param listDependInstallMark 因wine依赖被标记的下标
      */
-    void removePackage(const int index);
+    void removePackage(int index);
 
-//// 重置状态相关函数
+    //// 重置状态相关函数
 public:
     /**
      * @brief reset 重置 PackageManager的状态
@@ -320,13 +267,8 @@ public:
      */
     void resetPackageDependsStatus(const int index);
 
-public:
-
-    QList<QByteArray> m_errorIndex;        //wine依赖错误的包的下标
-
-//// 依赖查找 获取等相关函数
+    //// 依赖查找 获取等相关函数
 private:
-
     /**
      * @brief checkDependsPackageStatus 检查依赖包的状态
      * @param choosed_set   被选择安装或卸载的包的集合
@@ -334,22 +276,30 @@ private:
      * @param depends       包的依赖列表
      * @return
      */
-    const PackageDependsStatus checkDependsPackageStatus(QSet<QString> &choosed_set, const QString &architecture,
+    const PackageDependsStatus checkDependsPackageStatus(QSet<QString> &choosed_set,
+                                                         const QString &architecture,
                                                          const QList<QApt::DependencyItem> &depends);
-    const PackageDependsStatus checkDependsPackageStatus(QSet<QString> &choosed_set, const QString &architecture,
-                                                         const QApt::DependencyItem &candicate);
-    const PackageDependsStatus checkDependsPackageStatus(QSet<QString> &choosed_set, const QString &architecture,
-                                                         const QApt::DependencyInfo &dependencyInfo);
+    const PackageDependsStatus
+    checkDependsPackageStatus(QSet<QString> &choosed_set, const QString &architecture, const QApt::DependencyItem &candicate);
+    const PackageDependsStatus checkDependsPackageStatus(QSet<QString> &choosed_set,
+                                                         const QString &architecture,
+                                                         const QApt::DependencyInfo &dependencyInfo,
+                                                         const QString &providesName = QString());
     /**
      * @brief packageCandidateChoose   查找包的依赖候选
      * @param choosed_set   包的依赖候选的集合
      * @param debArch       包的架构
      * @param dependsList   依赖列表
+       @param levelInfo     提供用于打印的软件包查找层级依赖信息
      */
-    void packageCandidateChoose(QSet<QString> &choosed_set, const QString &debArch,
-                                const QList<QApt::DependencyItem> &dependsList);
-    void packageCandidateChoose(QSet<QString> &choosed_set, const QString &debArch,
-                                const QApt::DependencyItem &candidateItem);
+    void packageCandidateChoose(QSet<QString> &choosed_set,
+                                const QString &debArch,
+                                const QList<QApt::DependencyItem> &dependsList,
+                                const QString &levelInfo);
+    void packageCandidateChoose(QSet<QString> &choosed_set,
+                                const QString &debArch,
+                                const QApt::DependencyItem &candidateItem,
+                                const QString &levelInfo);
 
     /**
      * @brief isInstalledConflict 是否存在下载冲突
@@ -358,8 +308,8 @@ private:
      * @param packageArch         包的架构
      * @return
      */
-    const ConflictResult isInstalledConflict(const QString &packageName, const QString &packageVersion,
-                                             const QString &packageArch);
+    const ConflictResult
+    isInstalledConflict(const QString &packageName, const QString &packageVersion, const QString &packageArch);
     /**
      * @brief isConflictSatisfy 是否冲突满足
      * @param arch              架构
@@ -369,6 +319,27 @@ private:
     const ConflictResult isConflictSatisfy(const QString &arch, QApt::Package *package);
     const ConflictResult isConflictSatisfy(const QString &arch, const QList<QApt::DependencyItem> &conflicts);
 
+    //带replaces的检查，如果判定待安装包可以替换冲突包，则认为不构成冲突
+    const ConflictResult isConflictSatisfy(const QString &arch,
+                                           const QList<DependencyItem> &conflicts,
+                                           const QList<DependencyItem> &replaces,
+                                           QApt::Package *targetPackage = nullptr);
+
+    // detect if targetPackage can replace installedPackage
+    bool targetPackageCanReplace(QApt::Package *targetPackage, QApt::Package *installedPackage);
+
+    //// 依赖查找 获取查找包是否为消极的反向依赖
+private:
+    /**
+     * @brief isNegativeReverseDepend 判断软件包 `reverseDepend` 是否是 `packageName` 的消极依赖包，
+     *      例如 冲突(Conflict)/替换(Replace)/破坏(Breaks) 这些包在卸载时将被跳过，
+     *      在 依赖(Depends) 字段设置包将不会被视为消极包。
+     * @param packageName   当前处理的软件包
+     * @param reverseDepend `packageName` 的反向依赖包
+     * @return `reverseDepend` 是否为 `packageName` 的消极依赖
+     */
+    bool isNegativeReverseDepend(const QString &packageName, const QApt::Package *reverseDepend);
+
 private:
     /**
      * @brief packageWithArch 从指定的架构上打包
@@ -377,11 +348,19 @@ private:
      * @param annotation    注解
      * @return  package指针
      */
-    QApt::Package *packageWithArch(const QString &packageName, const QString &sysArch,
-                                   const QString &annotation = QString());
+    QApt::Package *packageWithArch(const QString &packageName, const QString &sysArch, const QString &annotation = QString());
+
+    /**
+     * @brief checkPackageArchValid 检测通过包名 \a packageName 获取的软件包 \a package 架构
+     *      是否支持建议架构 \a suggestArch
+     * @param package       软件包
+     * @param packageName   软件包名称
+     * @param resloveArch   解析建议的软件包名称
+     * @return 软件包 \a package 支持 \a suggestArch 架构
+     */
+    bool checkPackageArchValid(const QApt::Package *package, const QString &packageName, const QString &suggestArch);
 
 private:
-
     // 卸载deepin-wine-plugin-virture 时无法卸载deepin-wine-helper. Temporary solution：Special treatment for these package
     QMap<QString, QString> specialPackage();
 
@@ -392,7 +371,7 @@ private:
      * @param packageName  当前包的包名
      * @return 创建成功后软链接的全路径
      */
-    QString SymbolicLink(QString previousName, QString packageName);
+    QString SymbolicLink(const QString &previousName, const QString &packageName);
 
     /**
      * @brief link          创建软链接
@@ -400,7 +379,7 @@ private:
      * @param packageName   包名
      * @return  创建软链接之后的路径
      */
-    QString link(QString linkPath, QString packageName);
+    QString link(const QString &linkPath, const QString &packageName);
 
     /**
      * @brief mkTempDir 创建存放软链接的临时路径
@@ -408,7 +387,7 @@ private:
      */
     bool mkTempDir();
 
-    //使用软连接方式解决文件路径中存在空格的问题。
+    // 使用软连接方式解决文件路径中存在空格的问题。
     /**
      * @brief rmTempDir 删除存放软链接的临时目录
      * @return 删除临时目录的结果
@@ -416,27 +395,13 @@ private:
     bool rmTempDir();
 
 private:
-
     /**
      * @brief addPackage   添加包的处理槽函数
      * @param validPkgCount 有效包的数量
      * @param packagePath   此次添加包的路径
      * @param packageMd5Sum 此次添加的包的md5值
      */
-    void addPackage(int validPkgCount, QString packagePath, QByteArray packageMd5Sum);
-
-    /**
-     * @brief swapPackages   对列表中第一个包位置交换
-     * @param packagePath    包的路径
-     */
-    void swapPackages(const QString &packagePath);
-
-    /**
-     * @brief swappedPackageIndex 获取当前包要插入的位置
-     * @param packagePath     包的路径
-     * @return
-     */
-    int swappedPackageIndex(const QString &packagePath);
+    void addPackage(int validPkgCount, const QString &packagePath, const QByteArray &packageMd5Sum);
 
     /**
      * @brief getAllDepends 获取安装包所有依赖
@@ -444,7 +409,7 @@ private:
      * @param architecture  安装包架构
      * @return
      */
-    QList<QString> getAllDepends(const QList<DependencyItem> &depends,QString architecture);
+    QList<QString> getAllDepends(const QList<DependencyItem> &depends, const QString &architecture);
 
     /**
      * @brief getAllDepends 获取依赖包所有依赖
@@ -452,7 +417,7 @@ private:
      * @param architecture  架构
      * @return
      */
-    QList<QString> getAllDepends(const QString &packageName,QString architecture);
+    QList<QString> getAllDepends(const QString &packageName, const QString &architecture);
 
     /**
      * @brief refreshPage 刷新当前的页面
@@ -465,12 +430,12 @@ private:
      * @param packages 要添加的包
      * @param allPackageSize 要添加的包的数量
      */
-    void appendNoThread(QStringList packages, int allPackageSize);
+    void appendNoThread(const QStringList &packages, int allPackageSize);
 
     /**
      * @brief checkInvalid 检查有效文件的数量
      */
-    void checkInvalid(QStringList packages);
+    void checkInvalid(const QStringList &packages);
 
     /**
      * @brief dealInvalidPackage 处理无效的安装包
@@ -479,7 +444,7 @@ private:
      *   true   : 文件能打开
      *   fasle  : 文件不在本地或无权限
      */
-    bool dealInvalidPackage(QString packagePath);
+    bool dealInvalidPackage(const QString &packagePath);
 
     /**
      * @brief dealPackagePath 处理包的路径
@@ -489,7 +454,9 @@ private:
      *      1： 相对路径             --------> 转化为绝对路径
      *      2： 包的路径中存在空格     --------> 使用软链接，链接到/tmp下
      */
-    QString dealPackagePath(QString packagePath);
+    QString dealPackagePath(const QString &packagePath);
+
+    Pkg::DependsPair getPackageDependsDetail(const int index);
 
 private slots:
     /**
@@ -498,14 +465,13 @@ private slots:
     void slotAppendPackageFinished();
 
 private:
-
     /**
      * @brief 判断当前应用是否为黑名单应用
      *
      * @return true 是黑名单应用
      * @return false 不是黑名单应用
      */
-    bool isBlackApplication(QString applicationName);
+    bool isBlackApplication(const QString &applicationName);
 
     /**
      * @brief 获取当前黑名单应用列表
@@ -513,21 +479,28 @@ private:
      */
     void getBlackApplications();
 
+    /**
+       @brief 过滤已安装或无需更新的Wine软件包
+     */
+    void filterNeedInstallWinePackage(QStringList &dependList,
+                                      const DebFile &debFile,
+                                      const QHash<QString, DependencyInfo> &dependInfoMap);
+
+    void refreshPackageMarkedInfo(const QByteArray &md5, const QString &filePath);
+
 private:
+    QMap<QByteArray, int> m_errorIndex;  // wine依赖错误的包的下标 QMap<MD5, DebListModel::DependsAuthStatus>
 
-    //安装程序后端指针(异步加载)
-    QFuture<QApt::Backend *> m_backendFuture;           
+    // 存放包路径的列表
+    QList<QString> m_preparedPackages = {};
 
-    //存放包路径的列表
-    QList<QString> m_preparedPackages       = {};   
+    // 存放包MD5的集合
+    QSet<QByteArray> m_appendedPackagesMd5 = {};
 
-    //存放包MD5的集合       
-    QSet<QByteArray> m_appendedPackagesMd5  = {};
+    QMap<QString, QByteArray> m_allPackages;  // 存放有效包路径及md5，避免二次获取消耗时间
 
-    QMap<QString, QByteArray> m_allPackages; //存放有效包路径及md5，避免二次获取消耗时间
-
-    //包MD5与下标绑定的list
-    QList<QByteArray> m_packageMd5          = {};
+    // 包MD5与下标绑定的list
+    QList<QByteArray> m_packageMd5 = {};
 
     /**
      * @brief m_packageMd5DependsStatus 包的依赖状态的Map
@@ -542,6 +515,13 @@ private:
      */
     QMap<QByteArray, PackageDependsStatus> m_packageMd5DependsStatus;
 
+    /**
+       @brief The key is md5, the value is the dependent info of the package,
+            marked packages NewInstall/ToUpgrade/ToRemove...
+            If the status of other packages is not changed, the value is nullptr.
+     */
+    QMap<QByteArray, QSharedPointer<Deb::DebPackage>> m_markedDepends;
+
     /**
      * @brief m_packageInstallStatus 包安装状态的Map
      * int: 包的下标
@@ -554,21 +534,28 @@ private:
      */
     QMap<QByteArray, int> m_packageInstallStatus = {};
 
-    QByteArray m_currentPkgMd5; //当前包的md5
+    QByteArray m_currentPkgMd5;  // 当前包的md5
 
     /**
      * @brief m_dependsPackages  包依赖关系的map
      * QPair<QList<dependInfo>, QList<dependInfo>> 仓库可获取依赖与仓库不可获取依赖
      * 与md5进行绑定
      */
-    QMap<QByteArray, QPair<QList<DependInfo>, QList<DependInfo>>> m_dependsPackages;
-    DependInfo m_dinfo; //依赖包的包名及版本
+    QMap<QByteArray, Pkg::DependsPair> m_dependsPackages;
+    Pkg::DependInfo m_dinfo;  // 依赖包的包名及版本
+
+    /**
+       @brief m_loopErrorDeepends 循环判断依赖时缓存非 Ok 的前置包状态
+        用于对 OR 或依赖及 Provides 虚包依赖在循环中依赖中返回前置已检测的包状态，
+        而不是直接返回 Ok .
+     */
+    QHash<QString, int> m_loopErrorDeepends;
 
     // wine应用处理的下标
     int m_DealDependIndex = -1;
 
-    //下载依赖的线程
-    DealDependThread *m_installWineThread        = nullptr;    
+    // 下载依赖的线程
+    DealDependThread *m_installWineThread = nullptr;
 
     /**
      * @brief m_dependInstallMark wine依赖下标的标记
@@ -576,17 +563,15 @@ private:
      */
     QList<QByteArray> m_dependInstallMark = {};
 
-    QPair<QList<DependInfo>, QList<DependInfo>> m_pair; //存储available及broken依赖
+    QPair<QList<Pkg::DependInfo>, QList<Pkg::DependInfo>> m_pair;  // 存储available及broken依赖
 
-    QList<QString> m_allDependsList; //存储当前添加的包的所有依赖
+    QList<QString> m_allDependsList;  // 存储当前添加的包的所有依赖
 
 private:
-    const QString m_tempLinkDir = "/tmp/LinkTemp/";     //软链接临时路径
+    const QString m_tempLinkDir = "/tmp/LinkTemp/";  // 软链接临时路径
 
 private:
-    AddPackageThread *m_pAddPackageThread = nullptr;    //添加包的线程
-
-    bool installWineDepends = false;
+    AddPackageThread *m_pAddPackageThread = nullptr;  // 添加包的线程
 
     bool isDependsExists = false;
 
@@ -598,15 +583,17 @@ private:
 
     QString m_currentPkgName = "";
 
-    QStringList m_blackApplicationList = {}; //域管黑名单
+    QStringList m_blackApplicationList = {};  // 域管黑名单
 
-    QList<QVector<QString>> m_orDepends; //存储或依赖关系
+    QList<QVector<QString>> m_orDepends;  // 存储或依赖关系
 
-    QList<QVector<QString>> m_unCheckedOrDepends; //存储还未检测的或依赖关系
+    QList<QVector<QString>> m_unCheckedOrDepends;  // 存储还未检测的或依赖关系
 
-    QMap<QString, PackageDependsStatus> m_checkedOrDependsStatus; //存储检测完成的或依赖包及其依赖状态
+    QMap<QString, PackageDependsStatus> m_checkedOrDependsStatus;  // 存储检测完成的或依赖包及其依赖状态
 
-    QMap<QString, DependencyInfo> m_dependsInfo; //所有依赖的信息
+    QMap<QString, DependencyInfo> m_dependsInfo;  // 所有依赖的信息
+
+    DependGraph m_dependGraph;  // 依赖关系图计算器
 };
 
 #endif  // PACKAGESMANAGER_H
