@@ -1,25 +1,14 @@
-/*
-* Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd.
-*
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
-
+// SPDX-FileCopyrightText: 2022 - 2023 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #ifndef DEBLISTMODEL_H
 #define DEBLISTMODEL_H
 
 #include "manager/packagesmanager.h"
+#include "process/Pty.h"
+#include "abstract_package_list_model.h"
+#include "utils/deb_package.h"
 
 #include <QApt/Backend>
 #include <QApt/DebFile>
@@ -40,6 +29,12 @@
 DWIDGET_USE_NAMESPACE
 
 class AptConfigMessage;
+namespace Compatible {
+class CompatibleProcessController;
+}
+namespace Immutable {
+class ImmutableProcessController;
+}
 
 class Dialog : public DDialog
 {
@@ -51,13 +46,12 @@ signals:
     void signalClosed();
 };
 
-class DebListModel : public QAbstractListModel
+class DebListModel : public AbstractPackageListModel
 {
     Q_OBJECT
 
 public:
     explicit DebListModel(QObject *parent = nullptr);
-
     ~DebListModel() override;
 
     /**
@@ -79,98 +73,7 @@ public:
      * @param errorInfo 库返回的或自定义的安装错误的原因
      * @return 要显示的安装失败的原因
      */
-    static const QString workerErrorString(const int errorCode, const QString errorInfo);
-    /**
-     * @brief The PackageRole enum
-     * 包的各种数据角色
-     */
-    enum PackageRole {
-        PackageNameRole = Qt::DisplayRole,   //包名
-        UnusedRole = Qt::UserRole,           //
-        WorkerIsPrepareRole,                //当前工作是否处于准备状态
-        ItemIsCurrentRole,                  //获取当前下标
-        PackageVersionRole,                 //包的版本
-        PackagePathRole,                    //包的路径
-        PackageInstalledVersionRole,        //包已经安装的版本
-        PackageShortDescriptionRole,        //包的短描述
-        PackageLongDescriptionRole,         //包的长描述
-        PackageVersionStatusRole,           //包的安装状态
-        PackageDependsStatusRole,           //包的依赖状态
-        PackageAvailableDependsListRole,    //包可用的依赖
-        PackageFailReasonRole,              //包安装失败的原因
-        PackageOperateStatusRole,           //包的操作状态
-        PackageReverseDependsListRole,      //依赖于此包的程序
-    };
-
-    /**
-     * @brief The WorkerStatus enum
-     * 安装器的工作状态
-     */
-    enum WorkerStatus {
-        WorkerPrepare,                          //准备，可以进行安装或卸载
-        WorkerProcessing,                       //正在安装
-        WorkerFinished,                         //安装结束
-        WorkerUnInstall                         //正在卸载
-    };
-
-    /**
-     * @brief The PackageInstallStatus enum
-     * 包的安装状态
-     */
-    enum PackageInstallStatus {
-        NotInstalled,                           //当前包没有被安装
-        InstalledSameVersion,                   //当前已经安装过相同的版本
-        InstalledEarlierVersion,                //当前已经安装过较早的版本
-        InstalledLaterVersion,                  //当前已经安装过更新的版本
-    };
-
-    /**
-     * @brief The PackageDependsStatus enum
-     * 当前包的依赖状态
-     */
-    enum DependsStatus {
-        DependsOk,              //依赖满足
-        DependsAvailable,       //依赖可用但是需要下载
-        DependsBreak,           //依赖不满足
-        DependsVerifyFailed,    //签名验证失败
-        DependsAuthCancel,      //依赖授权失败（wine依赖）
-        ArchBreak,              //架构不满足（此前架构不满足在前端验证，此后会优化到后端）//2020-11-19 暂时未优化
-        Prohibit,               //应用被域管限制，无法安装
-    };
-
-    /**
-     * @brief The PackageOperationStatus enum
-     * 包的当前操作状态
-     */
-    enum PackageOperationStatus {
-        Prepare,                                //准备安装
-        Operating,                              //正在安装
-        Success,                                //安装成功
-        Failed,                                 //安装失败
-        Waiting,                                //等待安装
-        VerifyFailed,                           //签名验证失败
-    };
-
-    /**
-     * @brief The DependsAuthStatus enum
-     * wine 依赖安装时的状态
-     */
-    enum DependsAuthStatus {
-        AuthBefore,         //鉴权框弹出之前
-        AuthPop,            //鉴权框弹出
-        CancelAuth,         //鉴权取消
-        AuthConfirm,        //鉴权确认后
-        AuthDependsSuccess, //安装成功
-        AuthDependsErr,     //安装失败
-        AnalysisErr,        //解析错误
-    };
-
-    enum ErrorCode {
-        NoDigitalSignature      = 101, //无有效的数字签名
-        DigitalSignatureError,         //数字签名校验失败
-        ConfigAuthCancel        = 127, //配置安装授权被取消
-        ApplocationProhibit     = 404, //当前包在黑名单中禁止安装
-    };
+    static const QString workerErrorString(const int errorCode, const QString &errorInfo);
 
     /**
      * @brief reset
@@ -179,7 +82,7 @@ public:
      * 清空安装错误的缓存
      * 重置packageManage的状态
      */
-    void reset();
+    void reset() override;
 
     /**
      * @brief resetFilestatus
@@ -188,11 +91,7 @@ public:
      */
     void resetFileStatus();
 
-    /**
-     * @brief isWorkerPrepare 获取当前的工作状态是否是就绪状态
-     * @return 当前是否就绪
-     */
-    bool isWorkerPrepare() const;
+    void resetInstallStatus() override;
 
     /**
      * @brief isReady 查看后端初始化的状态
@@ -227,18 +126,14 @@ public:
      */
     QVariant data(const QModelIndex &index, int role) const override;
 
+    bool setData(const QModelIndex &index, const QVariant &value, int role = Qt::EditRole) override;
+
     /**
      * @brief isDevelopMode 是否是开发者模式
      * @return
      */
     bool isDevelopMode();
 
-    /**
-     * @brief selectedIndexRow 当前选择安装包列表的行
-     * @param row 行号
-     */
-    void selectedIndexRow(int row);
-
 public:
     /**
      * @brief initPrepareStatus  初始化所有包的状态为Prepare
@@ -253,59 +148,43 @@ public:
     int getInstallFileSize();
 
 public:
-    /**
-     * @brief getWorkerStatus 获取当前安装器的安装状态
-     * @return 当前安装器的安装状态
-     */
-    int getWorkerStatus();
-
-    /**
-     * @brief setWorkerStatus 设置当前安装器的安装状态
-     * @param workerStatus 当前需要设置的安装状态
-     */
-    void setWorkerStatus(int workerStatus);
-
     /**
      * @brief removePackage 删除某一个包
      * @param idx 要删除的包的index
      */
-    void removePackage(const int idx);
+    void removePackage(const int idx) override;
+
+    /**
+     * @brief checkPackageDigitalSignature 查找指定包安装状态
+     * @param package_path 路径
+     */
+    Pkg::PackageInstallStatus checkInstallStatus(const QString &package_path) override;
+    /**
+     * @brief searchPackageInstallInfo 查找指定包依赖
+     * @param package_path 路径
+     */
+    Pkg::DependsStatus checkDependsStatus(const QString &package_path) override;
+    /**
+     * @brief searchPackageInstallInfo 查找指定包数字签名
+     * @param package_path 路径
+     */
+    int checkDigitalSignature(const QString &package_path);
+    /**
+     * @brief searchPackageInstallInfo 查找指定包信息
+     * @param package_path 路径
+     */
+    QStringList getPackageInfo(const QString &package_path) override;
+
+    QString lastProcessError() override;
+    bool containsSignatureFailed() const override;
+
+    /**
+     * @brief checkPackageValid 查找指定包信息
+     * @param package_path 路径
+     */
+    QString checkPackageValid(const QString &package_path) override;
 
 signals:
-    /**
-     * @brief signalLockForAuth  授权框弹出后 禁用按钮  授权框取消后，启用按钮
-     * @param lock 启用/禁用按钮
-     */
-    void signalLockForAuth(const bool lock) const;
-
-    /**
-     * @brief signalAuthCancel    授权取消
-     */
-    void signalAuthCancel();
-
-    /**
-     * @brief signalStartInstall  开始安装
-     */
-    void signalStartInstall();
-
-    /**
-     * @brief signalWorkerFinished  安装结束
-     */
-    void signalWorkerFinished() const;
-
-    /**
-     * @brief signalTransactionProgressChanged
-     * 某一个包的安装进度改变
-     * @param progress
-     */
-    void signalTransactionProgressChanged(const int progress) const;
-
-    /**
-     * @brief signalWorkerProgressChanged 整体的安装进度改变
-     * @param progress
-     */
-    void signalWorkerProgressChanged(const int progress) const;
-
     /**
      * @brief signalPackageOperationChanged 包操作状态改变
      * @param index 包的index
@@ -320,100 +199,6 @@ signals:
      */
     void signalPackageDependsChanged(const QModelIndex &index, int status) const;
 
-    /**
-     * @brief signalAppendOutputInfo      安装输出信息
-     * @param info      要显示的信息
-     */
-    void signalAppendOutputInfo(const QString &info) const;
-
-    /**
-     * @brief signalChangeOperateIndex  index 被修改
-     * @param opIndex       修改后的index
-     */
-    void signalChangeOperateIndex(int opIndex);
-
-    /**
-     * @brief signalEnableReCancelBtn         授权框弹出后禁用按钮，授权框取消后启用按钮
-     * @param bEnable       启用/禁用按钮的标识
-     */
-    void signalEnableReCancelBtn(bool bEnable);
-
-    /**
-     * @brief signalDependResult  依赖下载的状态
-     */
-    void signalDependResult(int, QString);
-
-    /**
-     * @brief signalEnableCloseButton        设置关闭按钮是否可用
-     */
-    void signalEnableCloseButton(bool);
-
-    /**
-     * @brief signalInvalidPackage 无效包的信号
-     */
-    void signalInvalidPackage();
-
-    /**
-     * @brief signalNotLocalPackage 包不在本地的信号
-     *
-     * ps: 包不在本地无法安装
-     */
-    void signalNotLocalPackage();
-
-    /**
-     * @brief signalPackageCannotFind 包已经被移动的信号 通知前端发送浮动消息
-     * @param packageName 被移动的文件名
-     */
-    void signalPackageCannotFind(QString packageName) const;
-
-
-    /**
-     * @brief signalPackageAlreadyExists 包已添加的信号
-     */
-    void signalPackageAlreadyExists();
-
-    /**
-     * @brief signalSingleDependPackages 单包依赖关系显示信号
-     * @param breakPackages
-     */
-    void signalSingleDependPackages(DependsPair breakPackages, bool intallWineDepends);
-
-    /**
-     * @brief signalMultDependPackages 批量包依赖关系显示信号
-     * @param breakPackages
-     */
-    void signalMultDependPackages(DependsPair breakPackages, bool intallWineDepends);
-signals:
-    /**
-     * @brief signalRefreshSinglePage 刷新单包安装界面的信号
-     */
-    void signalRefreshSinglePage();
-
-    /**
-     * @brief signalRefreshMultiPage 刷新批量安装model的信号
-     */
-    void signalRefreshMultiPage();
-
-    /**
-     * @brief signalSingle2MultiPage 刷新批量安装的信号
-     */
-    void signalSingle2MultiPage();
-
-    /**
-     * @brief signalRefreshFileChoosePage 刷新首页
-     */
-    void signalRefreshFileChoosePage();
-
-    /**
-     * @brief signalAppendStart 正在添加的信号
-     */
-    void signalAppendStart();
-
-    /**
-     * @brief signalAppendFinished 添加结束的信号
-     */
-    void signalAppendFinished();
-
 public slots:
 
     /**
@@ -425,19 +210,19 @@ public slots:
     /**
      * @brief slotInstallPackages 开始安装所有的包
      */
-    void slotInstallPackages();
+    bool slotInstallPackages() override;
 
     /**
      * @brief slotUninstallPackage     卸载某一个包
      * @param index   包的index
      */
-    void slotUninstallPackage(const int index);
+    bool slotUninstallPackage(int index) override;
 
     /**
      * @brief slotAppendPackage 添加包
      * @param package 添加的包的路径
      */
-    void slotAppendPackage(QStringList packages);
+    void slotAppendPackage(const QStringList &packages) override;
 
     /**
      * @brief slotTransactionErrorOccurred 安装过程中出现错误
@@ -456,13 +241,13 @@ public slots:
      * @param dependIndex   依赖包的index（因为这个包的依赖不被满足）
      * @param dependName    发生依赖安装失败的依赖名称
      */
-    void slotDealDependResult(int authType, int dependIndex, QString dependName);
+    void slotDealDependResult(int authType, int dependIndex, const QString &dependName);
 
 public slots:
     /**
      * @brief slotConfigReadOutput 处理配置包的输出并显示
      */
-    void slotConfigReadOutput();
+    void slotConfigReadOutput(const char *buffer, int length, bool isCommandExec);
 
     /**
      * @brief slotConfigInstallFinish 配置结束
@@ -474,7 +259,7 @@ public slots:
      * @brief slotConfigInputWrite 配置的输入数据处理
      * @param str 输入的数据（一般是输入的选项）
      */
-    void slotConfigInputWrite(QString str);
+    void slotConfigInputWrite(const QString &str);
 
     /**
      * @brief slotCheckInstallStatus 根据命令返回的消息判断安装状态
@@ -482,7 +267,7 @@ public slots:
      * 如果命令返回的信息是Cannot run program deepin-deb-installer-dependsInstall: No such file or directory
      * 意味着当前/usr/bin下没有deepin-deb-installer-dependsInstall命令，此版本有问题，需要重新安装deepin-deb-installer-dependsInstall命令
      */
-    void slotCheckInstallStatus(QString str);
+    void slotCheckInstallStatus(const QString &str);
 
 private slots:
 
@@ -542,7 +327,6 @@ private slots:
     void slotShowProhibitWindow();
 
 private:
-
     /**
      * @brief setEndEnable  授权框取消，按钮启用
      */
@@ -577,7 +361,7 @@ private:
      * @brief refreshOperatingPackageStatus 刷新当前操作的包的操作状态
      * @param oprationStatus  要修改的操作状态
      */
-    void refreshOperatingPackageStatus(PackageOperationStatus oprationStatus);
+    void refreshOperatingPackageStatus(Pkg::PackageOperationStatus oprationStatus);
 
     /**
      * @brief packageFailedReason  获取包安装失败的原因
@@ -592,12 +376,6 @@ private:
     void initRowStatus();
 
 private:
-    /**
-     * @brief checkSystemVersion  check 当前操作系统的版本
-     * 个人版专业版需要验证数字签名，其余版本不需要
-     */
-    void checkSystemVersion();
-
     /**
      * @brief checkDigitalSignature  检查数字签名
      * @return  检查当前包是否有数字签名
@@ -611,13 +389,20 @@ private:
 
     /**
      * @brief showNoDigitalErrWindow 弹出数字签名校验错误的错误弹窗
+     * @param recordError 是否记录错误信息，引入分级验签后，允许只提示验签错误信息，
+     *  不涉及状态切换及更新记录
      */
-    void showDigitalErrWindow();
+    void showDigitalErrWindow(bool recordError = true);
 
     /**
      * @brief showDevelopDigitalErrWindow 开发者模式下弹出数字签名无效的弹窗
      */
-    void showDevelopDigitalErrWindow(ErrorCode code);
+    void showDevelopDigitalErrWindow(Pkg::ErrorCode code);
+
+    /**
+     * @brief showNoDigitalErrWindowInDdimProcess DDIM流程下的签名错误弹窗
+     */
+    void showNoDigitalErrWindowInDdimProcess(void (DebListModel::*failedFunction)());
 
     /**
      * @brief showProhibitWindow 弹出数字签名校验错误的错误弹窗
@@ -634,53 +419,26 @@ private:
 
     /**
      * @brief 数字签名校验失败 弹窗处理的槽函数
-     * 
+     *
      * @param errorCode 错误原因代码
      */
-    void digitalVerifyFailed(ErrorCode errorCode);
+    void digitalVerifyFailed(Pkg::ErrorCode errorCode);
 
 private:
-
-    /**
-     * @brief checkTemplate 检查是否需要配置
-     * @param debPath   包的路径
-     * @return  是否需要配置
-     */
-    bool checkTemplate(QString debPath);
-
-    /**
-     * @brief getDebian    获取包的DEBIAN文件
-     * @param debPath      包的路径
-     */
-    void getDebian(QString debPath);
-
-    /**
-     * @brief mkdir     创建临时目录 ，存放DEBIAN文件
-     * @return  是否创建成功
-     */
-    bool mkdir();
-
-    /**
-     * @brief rmdir     删除临时目录
-     *
-     */
-    void rmdir();
-
     /**
      * @brief enableTitleBarFocus
      * 启用TitleBar焦点切换策略
      */
     void enableTitleBarFocus();
 
-
     /**
      * @brief Get the Package Md5 object
-     * 
+     *
      * @param packagesMD5 所有包的md5的列表
      */
     void getPackageMd5(const QList<QByteArray> &packagesMD5);
 
-//// 文件移动、删除、修改检查
+    //// 文件移动、删除、修改检查
 private:
     /**
      * @brief recheckPackagePath 重新检查文件路径
@@ -689,7 +447,7 @@ private:
      *         true : 文件存在
      *         false: 文件不存在
      */
-    bool recheckPackagePath(QString packagePath) const;
+    bool recheckPackagePath(const QString &packagePath) const;
 
 private:
     /**
@@ -712,54 +470,78 @@ private:
      */
     void initRefreshPageConnecions();
 
+    /**
+       @brief printDependsChanges 打印安装的依赖包变更
+     */
+    void printDependsChanges();
+
+    QString itemToolTips(int index) const;
+
+    // Compatbile interface
+    // compatible mode only support single package install/uninstall.
+    [[nodiscard]] inline bool supportCompatible() const { return 1 == m_packagesManager->m_preparedPackages.size(); }
+
+    void ensureCompatibleProcessor();
+    [[nodiscard]] bool installCompatiblePackage();
+    [[nodiscard]] bool uninstallCompatiblePackage();
+
+    // Immutable interface
+    void ensureImmutableProcessor();
+    [[nodiscard]] bool installImmutablePackage();
+    [[nodiscard]] bool uninstallImmutablePackage();
+
+    Deb::DebPackage::Ptr packagePtr(int index) const;
+
 private:
-    //当前工作状态
-    int m_workerStatus                  = 0;
+    // 当前正在操作的index
+    int m_operatingIndex = 0;
 
-    //当前正在操作的index
-    int m_operatingIndex                = 0;
+    // 当前正在操作的状态的index
+    int m_operatingStatusIndex = 0;
 
-    //当前正在操作的状态的index
-    int m_operatingStatusIndex          = 0;
+    // 当前正在处理的包的md5
+    QByteArray m_operatingPackageMd5 = nullptr;
 
-    //当前正在处理的包的md5
-    QByteArray m_operatingPackageMd5    = nullptr;
-
-
-    //当前的index
+    // 当前的index
     QModelIndex m_currentIdx;
 
-    //后端类
+    // 后端类
     PackagesManager *m_packagesManager = nullptr;
 
-    //当前正在运行的Trans
+    // 当前正在运行的Trans
     QPointer<QApt::Transaction> m_currentTransaction;
 
-    //所有包的操作状态Map
+    // 所有包的操作状态Map
     QMap<QByteArray, int> m_packageOperateStatus = {};
-
-    //FailCode 错误代码 ，trans返回的错误代码
+    // FailCode 错误代码 ，trans返回的错误代码
     QMap<QByteArray, int> m_packageFailCode = {};
+    // FailReason , trans返回的详细错误信息
+    QMap<QByteArray, QString> m_packageFailReason = {};
 
-    //FailReason , trans返回的详细错误信息
-    QMap<QByteArray, QString> m_packageFailReason= {};
+    QList<QByteArray> m_packageMd5 = {};
 
     // 配置安装进程
-    QProcess *m_procInstallConfig = {};
-
-    // 配置的临时目录
-    const QString tempPath = "/tmp/DEBIAN";
+    Konsole::Pty *m_procInstallConfig = {};
 
     QString m_brokenDepend = "";
 
     // 开发者模式的标志变量
-    //部分系统版本无需签名验证，默认开发者模式
+    // 部分系统版本无需签名验证，默认开发者模式
     bool m_isDevelopMode = true;
     bool m_isDigitalVerify = false;
 
-    QList<QByteArray> m_packageMd5 = {};
-
     AptConfigMessage *configWindow = nullptr;
+
+    // 当前安装是否存在分级管控签名验证失败
+    bool m_hierarchicalVerifyError = false;
+
+    // Compatible
+    Deb::DebPackage::Ptr m_currentPackage;
+    QMap<QByteArray, Deb::DebPackage::Ptr> m_packagePtrMap;
+    QScopedPointer<Compatible::CompatibleProcessController> m_compProcessor;
+
+    // immutable
+    QScopedPointer<Immutable::ImmutableProcessController> m_immProcessor;
 };
 
 #endif  // DEBLISTMODEL_H
