@@ -1,19 +1,6 @@
-/*
-* Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd.
-*
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #ifndef INSTALLER_H
 #define INSTALLER_H
@@ -26,11 +13,11 @@
 class PackagesManager;
 class Package;
 
-class PackageInstaller: public QObject
+class PackageInstaller : public QObject
 {
     Q_OBJECT
 public:
-    PackageInstaller(QApt::Backend *b);
+    explicit PackageInstaller(QApt::Backend *b);
 
     virtual ~PackageInstaller();
 
@@ -66,12 +53,11 @@ private:
 
     void installAvailableDepends();
 
-
 private:
-    Package *m_packages         = nullptr;
+    Package *m_packages = nullptr;
 
-    QApt::Backend *m_backend    = nullptr;
+    QApt::Backend *m_backend = nullptr;
     QApt::Transaction *m_pTrans = nullptr;
 };
 
-#endif // INSTALLER_H
+#endif  // INSTALLER_H
