@@ -1,3 +1,7 @@
+# SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+#
+# SPDX-License-Identifier: CC0-1.0
+
 utdir=build-ut
 rm -r $utdir
 rm -r ../$utdir
@@ -17,7 +21,7 @@ lcov -d $workdir -c -o ./report/coverage.info
 
 lcov --extract ./report/coverage.info '*/src/*' -o ./report/coverage.info
 
-lcov --remove ./report/coverage.info '*/tests/*' -o ./report/coverage.info
+lcov --remove ./report/coverage.info '*/tests/*' '*/process/*' -o ./report/coverage.info
 
 genhtml -o ./report ./report/coverage.info
 
