@@ -1,27 +1,16 @@
-/*
-* Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd.
-*
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include <gtest/gtest.h>
 
 #include "../deb-installer/model/deblistmodel.h"
 #include "../deb-installer/manager/packagesmanager.h"
 #include "../deb-installer/manager/PackageDependsStatus.h"
-#include "utils/utils.h"
-#include "utils/result.h"
+#include "../deb-installer/utils/utils.h"
+#include "../deb-installer/utils/result.h"
+#include "../deb-installer/utils/hierarchicalverify.h"
+#include "../deb-installer/view/widgets/error_notify_dialog_helper.h"
 
 #include <stub.h>
 
@@ -33,8 +22,6 @@
 
 using namespace QApt;
 
-
-
 class ut_DebListModel_test : public ::testing::Test
 {
     // Test interface
@@ -45,6 +32,7 @@ protected:
 
     DebListModel *m_debListModel = nullptr;
     Stub stub;
+    Stub stubHierachicalInvalid;
 };
 
 bool model_backend_init()
@@ -52,9 +40,7 @@ bool model_backend_init()
     return true;
 }
 
-void model_checkSystemVersion()
-{
-}
+void model_checkSystemVersion() {}
 
 bool model_BackendReady()
 {
@@ -74,7 +60,6 @@ void stub_model_open(const std::string &__s, std::ios_base::openmode __mode)
     qDebug() << "stb——open";
 }
 
-
 QString model_deb_arch_i386()
 {
     return "i386";
@@ -115,7 +100,6 @@ QString model_deb_version()
     return "version";
 }
 
-
 QList<DependencyItem> model_deb_conflicts()
 {
     DependencyInfo info("packageName", "0.0", RelationType::Equals, Depends);
@@ -157,7 +141,6 @@ bool model_stub_dealInvalidPackage(QString)
     return true;
 }
 
-
 Package *model_package_package(const QString &name)
 {
     return nullptr;
@@ -174,7 +157,6 @@ QList<DependencyItem> model_deb_depends()
     return conflicts;
 }
 
-
 void model_initRowStatus()
 {
     return;
@@ -197,16 +179,15 @@ QString model_packageManager_package(const int index)
 
 const QStringList model_packageManager_packageReverseDependsList(const QString &, const QString &)
 {
-
     return {};
 }
 
 void model_backend_markPackageForRemoval(const QString &)
 {
-    return ;
+    return;
 }
 
-void model_refreshOperatingPackageStatus(const DebListModel::PackageOperationStatus)
+void model_refreshOperatingPackageStatus(const Pkg::PackageOperationStatus)
 {
     return;
 }
@@ -216,7 +197,6 @@ QApt::Transaction *model_backend_commitChanges()
     return nullptr;
 }
 
-
 QByteArray model_package_getPackageMd5(const int)
 {
     return "";
@@ -252,7 +232,6 @@ bool stub_exists_false()
     return false;
 }
 
-
 static Dtk::Core::DSysInfo::UosEdition model_uosEditionType_UosEnterprise()
 {
     return Dtk::Core::DSysInfo::UosEnterprise;
@@ -310,7 +289,6 @@ Utils::VerifyResultCode model_Digital_Verify4(QString)
     return Utils::OtherError;
 }
 
-
 void model_bumpInstallIndex()
 {
     return;
@@ -369,10 +347,27 @@ qint64 ut_process_write(const QByteArray &)
     return 0;
 }
 
+bool stub_DebListModel_Hierarchical_Invalid()
+{
+    return false;
+}
+
+bool stub_DebListModel_Hierarchical_Valid()
+{
+    return true;
+}
+
+static int g_VerifyDeependErrCount = 0;
+void stub_DebListModel_showHierarchicalVerifyWindow_DoNothing()
+{
+    g_VerifyDeependErrCount++;
+}
+
 void ut_DebListModel_test::stubFunction()
 {
-    stub.set((void (std::fstream::*)(const std::string & __s, std::ios_base::openmode __mode))ADDR(std::fstream, open), stub_model_open);
-    stub.set((bool (std::fstream::*)())ADDR(std::fstream, is_open), stub_model_is_open);
+    stub.set((void(std::fstream::*)(const std::string &__s, std::ios_base::openmode __mode))ADDR(std::fstream, open),
+             stub_model_open);
+    stub.set((bool(std::fstream::*)())ADDR(std::fstream, is_open), stub_model_is_open);
 
     stub.set(ADDR(Backend, init), model_backend_init);
     stub.set(ADDR(Backend, architectures), model_backend_architectures);
@@ -384,7 +379,9 @@ void ut_DebListModel_test::stubFunction()
     stub.set(ADDR(Transaction, isCancellable), model_transaction_isCancellable);
     stub.set(ADDR(Transaction, isCancelled), model_transaction_isCancelled);
     stub.set(ADDR(Transaction, errorDetails), model_transaction_errorDetails);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     stub.set(ADDR(Transaction, setProperty), model_transaction_setProperty);
+#endif
     stub.set(ADDR(Transaction, exitStatus), model_transaction_exitStatus);
 
     stub.set(ADDR(DebFile, architecture), model_deb_arch_i386);
@@ -406,8 +403,11 @@ void ut_DebListModel_test::stubFunction()
     stub.set(ADDR(PackagesManager, package), model_packageManager_package);
     stub.set(ADDR(PackagesManager, dealInvalidPackage), model_stub_dealInvalidPackage);
 
-    stub.set((Package * (Backend::*)(const QString &) const)ADDR(Backend, package), model_package_package);
+    stub.set((Package * (Backend::*)(const QString &) const) ADDR(Backend, package), model_package_package);
+
+    stubHierachicalInvalid.set(ADDR(HierarchicalVerify, isValid), stub_DebListModel_Hierarchical_Invalid);
 }
+
 void ut_DebListModel_test::SetUp()
 {
     stubFunction();
@@ -432,6 +432,7 @@ TEST_F(ut_DebListModel_test, deblistmodel_UT_reset)
     EXPECT_TRUE(m_debListModel->m_packageFailCode.isEmpty());
     EXPECT_TRUE(m_debListModel->m_packageFailReason.isEmpty());
     EXPECT_TRUE(m_debListModel->m_packagesManager->m_errorIndex.isEmpty());
+    EXPECT_FALSE(m_debListModel->m_hierarchicalVerifyError);
 }
 
 TEST_F(ut_DebListModel_test, deblistmodel_UT_reset_filestatus)
@@ -443,7 +444,6 @@ TEST_F(ut_DebListModel_test, deblistmodel_UT_reset_filestatus)
     EXPECT_TRUE(m_debListModel->m_packageFailCode.isEmpty());
 }
 
-
 TEST_F(ut_DebListModel_test, deblistmodel_UT_isReady)
 {
     EXPECT_TRUE(m_debListModel->isReady());
@@ -539,14 +539,6 @@ TEST_F(ut_DebListModel_test, deblistmodel_UT_isDevelopMode)
     EXPECT_TRUE(m_debListModel->isDevelopMode());
 }
 
-TEST_F(ut_DebListModel_test, deblistmodel_UT_selectedIndexRow)
-{
-    QSignalSpy spy(m_debListModel->m_packagesManager, SIGNAL(signalMultDependPackages(DependsPair, bool)));
-    m_debListModel->m_packagesManager->m_packageMd5.insert(0, "sweat00001adscws1");
-    m_debListModel->selectedIndexRow(0);
-    EXPECT_EQ(1, spy.count());
-}
-
 TEST_F(ut_DebListModel_test, deblistmodel_UT_initPrepareStatus)
 {
     QStringList list;
@@ -554,7 +546,7 @@ TEST_F(ut_DebListModel_test, deblistmodel_UT_initPrepareStatus)
     m_debListModel->slotAppendPackage(list);
 
     m_debListModel->initPrepareStatus();
-    ASSERT_EQ(m_debListModel->m_packageOperateStatus[0], DebListModel::Prepare);
+    ASSERT_EQ(m_debListModel->m_packageOperateStatus[0], Pkg::PackageOperationStatus::Prepare);
 }
 
 TEST_F(ut_DebListModel_test, deblistmodel_UT_index)
@@ -563,7 +555,7 @@ TEST_F(ut_DebListModel_test, deblistmodel_UT_index)
     list << "/";
     m_debListModel->slotAppendPackage(list);
 
-    ASSERT_EQ(m_debListModel->index(0).data(DebListModel::PackageDependsStatusRole).toInt(), DebListModel::DependsOk);
+    ASSERT_EQ(m_debListModel->index(0).data(DebListModel::PackageDependsStatusRole).toInt(), Pkg::DependsStatus::DependsOk);
 }
 
 TEST_F(ut_DebListModel_test, deblistmodel_UT_getInstallFileSize)
@@ -637,7 +629,7 @@ TEST_F(ut_DebListModel_test, deblistmodel_UT_uninstallPackage1)
 {
     stub.set(ADDR(PackagesManager, packageReverseDependsList), model_packageManager_packageReverseDependsList);
     stub.set(ADDR(Backend, markPackageForRemoval), model_backend_markPackageForRemoval);
-//    stub.set((Package * (Backend::*)(const QString &) const)ADDR(Backend, package), stub_model_packageWithArch);
+    //    stub.set((Package * (Backend::*)(const QString &) const)ADDR(Backend, package), stub_model_packageWithArch);
     stub.set(ADDR(Package, setPurge), stub_setPurge);
     QStringList list;
     list << "/";
@@ -658,6 +650,11 @@ ConflictResult ut_packageConflictStat()
     return ConflictResult::err("");
 }
 
+PackageDependsStatus getPackageDependsStatus(const int)
+{
+    return PackageDependsStatus::_break("");
+}
+
 TEST_F(ut_DebListModel_test, deblistmodel_UT_packageFailedReason)
 {
     QStringList list;
@@ -669,6 +666,7 @@ TEST_F(ut_DebListModel_test, deblistmodel_UT_packageFailedReason)
     stub.set(ADDR(PackagesManager, isArchError), model_package_isArchError1);
     stub.set(ADDR(PackageDependsStatus, isBreak), ut_model_isBreak);
     stub.set(ADDR(PackagesManager, packageConflictStat), ut_packageConflictStat);
+    stub.set(ADDR(PackagesManager, getPackageDependsStatus), getPackageDependsStatus);
     m_debListModel->packageFailedReason(0);
     EXPECT_TRUE(m_debListModel->packageFailedReason(0).contains("Broken dependencies"));
 }
@@ -683,39 +681,37 @@ TEST_F(ut_DebListModel_test, deblistmodel_UT_initRowStatus)
 
     m_debListModel->initRowStatus();
 
-    ASSERT_EQ(m_debListModel->m_packageOperateStatus.find("deb").value(), DebListModel::Waiting);
+    ASSERT_EQ(m_debListModel->m_packageOperateStatus.find("deb").value(), Pkg::PackageOperationStatus::Waiting);
 }
 
 TEST_F(ut_DebListModel_test, deblistmodel_UT_checkSystemVersion_UosEnterprise)
 {
     stub.set(ADDR(Dtk::Core::DSysInfo, uosEditionType), model_uosEditionType_UosEnterprise);
-    m_debListModel->checkSystemVersion();
-    EXPECT_TRUE(m_debListModel->m_isDevelopMode);
+    EXPECT_TRUE(Utils::isDevelopMode());
 }
 
 TEST_F(ut_DebListModel_test, deblistmodel_UT_checkSystemVersion_UosProfessional)
 {
     stub.set(ADDR(Dtk::Core::DSysInfo, uosEditionType), model_uosEditionType_UosProfessional);
-    m_debListModel->checkSystemVersion();
+    Utils::isDevelopMode();
 }
 
 TEST_F(ut_DebListModel_test, deblistmodel_UT_checkSystemVersion_UosHome)
 {
     stub.set(ADDR(Dtk::Core::DSysInfo, uosEditionType), model_uosEditionType_UosHome);
-    m_debListModel->checkSystemVersion();
+    Utils::isDevelopMode();
 }
 
 TEST_F(ut_DebListModel_test, deblistmodel_UT_checkSystemVersion_UosCommunity)
 {
     stub.set(ADDR(Dtk::Core::DSysInfo, uosEditionType), model_uosEditionType_UosCommunity);
-    m_debListModel->checkSystemVersion();
-    EXPECT_TRUE(m_debListModel->m_isDevelopMode);
+    EXPECT_TRUE(Utils::isDevelopMode());
 }
 
 TEST_F(ut_DebListModel_test, deblistmodel_UT_checkSystemVersion_default)
 {
-    m_debListModel->checkSystemVersion();
-    EXPECT_TRUE(m_debListModel->m_isDevelopMode);
+    stub.set(ADDR(Dtk::Core::DSysInfo, uosEditionType), model_uosEditionType_default);
+    EXPECT_TRUE(Utils::isDevelopMode());
 }
 
 TEST_F(ut_DebListModel_test, deblistmodel_UT_checkDigitalSignature)
@@ -775,7 +771,7 @@ TEST_F(ut_DebListModel_test, deblistmodel_UT_checkDigitalSignature_03)
     m_debListModel->m_isDigitalVerify = true;
     stub.set((Utils::VerifyResultCode(*)(QString))ADDR(Utils, Digital_Verify), model_Digital_Verify2);
     ASSERT_TRUE(m_debListModel->checkDigitalSignature());
-    m_debListModel->showDevelopDigitalErrWindow(DebListModel::NoDigitalSignature);
+    m_debListModel->showDevelopDigitalErrWindow(Pkg::NoDigitalSignature);
     EXPECT_EQ(1, m_debListModel->preparedPackages().size());
 }
 
@@ -786,7 +782,6 @@ void model_digitalVerifyFailed()
 
 TEST_F(ut_DebListModel_test, deblistmodel_UT_showNoDigitalErrWindow)
 {
-
     stub.set(ADDR(DebListModel, digitalVerifyFailed), model_digitalVerifyFailed);
     QStringList list;
     list << "/";
@@ -817,7 +812,7 @@ TEST_F(ut_DebListModel_test, deblistmodel_UT_removePackage)
     m_debListModel->slotAppendPackage(list);
     m_debListModel->m_packageOperateStatus[""] = 1;
     m_debListModel->removePackage(0);
-    ASSERT_EQ(m_debListModel->m_packagesManager->m_preparedPackages.size(), 1);
+    ASSERT_EQ(m_debListModel->m_packagesManager->m_preparedPackages.size(), 0);
     ASSERT_TRUE(m_debListModel->m_packageOperateStatus.isEmpty());
 }
 
@@ -838,7 +833,7 @@ TEST_F(ut_DebListModel_test, deblistmodel_UT_onTransactionErrorOccurred)
     m_debListModel->m_operatingPackageMd5 = "deb";
     m_debListModel->m_packageOperateStatus.insert("deb", QApt::CommitError);
     m_debListModel->m_packageFailCode.insert("deb", QApt::FetchError);
-    m_debListModel->checkSystemVersion();
+    m_debListModel->m_isDevelopMode = Utils::isDevelopMode();
     m_debListModel->m_workerStatus = DebListModel::WorkerProcessing;
     m_debListModel->m_packageMd5.insert(0, "00000");
     m_debListModel->m_operatingIndex = 0;
@@ -848,28 +843,38 @@ TEST_F(ut_DebListModel_test, deblistmodel_UT_onTransactionErrorOccurred)
 
     m_debListModel->slotTransactionErrorOccurred();
     EXPECT_EQ(QApt::AuthError, m_debListModel->m_packageFailCode[m_debListModel->m_operatingPackageMd5]);
-    EXPECT_EQ(DebListModel::Failed, m_debListModel->m_packageOperateStatus[m_debListModel->m_operatingPackageMd5]);
+    EXPECT_EQ(Pkg::PackageOperationStatus::Failed, m_debListModel->m_packageOperateStatus[m_debListModel->m_operatingPackageMd5]);
     delete ut_sender();
 }
 
 TEST_F(ut_DebListModel_test, deblistmodel_UT_DealDependResult)
 {
-
     stub.set(ADDR(DebListModel, refreshOperatingPackageStatus), model_refreshOperatingPackageStatus);
     stub.set(ADDR(DebListModel, bumpInstallIndex), model_bumpInstallIndex);
     stub.set(ADDR(DebListModel, getPackageMd5), model_getPackageMd5);
 
     m_debListModel->slotDealDependResult(1, 0, "");
     m_debListModel->slotDealDependResult(2, 0, "");
-    EXPECT_EQ(DebListModel::Prepare, m_debListModel->m_packageOperateStatus["1"]);
+    EXPECT_EQ(Pkg::PackageOperationStatus::Prepare, m_debListModel->m_packageOperateStatus["1"]);
     m_debListModel->slotDealDependResult(3, 0, "");
     m_debListModel->slotDealDependResult(4, 0, "");
-    EXPECT_EQ(DebListModel::Prepare, m_debListModel->m_packageOperateStatus["1"]);
-    EXPECT_EQ(DebListModel::Prepare, m_debListModel->m_workerStatus);
+    EXPECT_EQ(Pkg::PackageOperationStatus::Prepare, m_debListModel->m_packageOperateStatus["1"]);
+    EXPECT_EQ(Pkg::PackageOperationStatus::Prepare, m_debListModel->m_workerStatus);
     m_debListModel->slotDealDependResult(5, 0, "");
     EXPECT_EQ("", m_debListModel->m_brokenDepend);
 }
 
+TEST_F(ut_DebListModel_test, deblistmodel_UT_DealDependResult_VerifyDependsErr)
+{
+    Stub tmpStub;
+    tmpStub.set(ADDR(ErrorNotifyDialogHelper, showHierarchicalVerifyWindow),
+                stub_DebListModel_showHierarchicalVerifyWindow_DoNothing);
+
+    g_VerifyDeependErrCount = 0;
+    m_debListModel->slotDealDependResult(DebListModel::VerifyDependsErr, 0, "");
+    EXPECT_EQ(g_VerifyDeependErrCount, 1);
+}
+
 TEST_F(ut_DebListModel_test, deblistmodel_UT_onTransactionStatusChanged)
 {
     TransactionStatus stat = TransactionStatus::AuthenticationStatus;
@@ -897,7 +902,19 @@ TEST_F(ut_DebListModel_test, deblistmodel_UT_bumpInstallIndex)
     m_debListModel->m_packageMd5.append("\n");
     m_debListModel->m_packageMd5.append("1");
     m_debListModel->bumpInstallIndex();
-    EXPECT_EQ("1", m_debListModel->m_operatingPackageMd5);
+    EXPECT_EQ("", m_debListModel->m_operatingPackageMd5);
+}
+
+TEST_F(ut_DebListModel_test, deblistmodel_UT_slotInstallPackages_resetHierarchicalVerify)
+{
+    stub.set(ADDR(DebListModel, installNextDeb), model_installNextDeb);
+    m_debListModel->m_operatingIndex = 0;
+    m_debListModel->m_packageMd5.append("\n");
+    m_debListModel->m_packageMd5.append("1");
+    m_debListModel->m_hierarchicalVerifyError = true;
+
+    m_debListModel->slotInstallPackages();
+    EXPECT_FALSE(m_debListModel->m_hierarchicalVerifyError);
 }
 
 TEST_F(ut_DebListModel_test, deblistmodel_UT_ConfigInstallFinish)
@@ -924,13 +941,15 @@ TEST_F(ut_DebListModel_test, deblistmodel_UT_ConfigReadOutput)
     m_debListModel->m_packageOperateStatus.insert("deb", QApt::CommitError);
 
     stub.set(ADDR(Konsole::Pty, receivedData), model_readAllStandardOutput);
-    const char *buffer = "111111"; int length = sizeof(buffer); bool isCommandExec = false;
-    m_debListModel->slotConfigReadOutput(buffer, length, isCommandExec);
-    EXPECT_EQ(DebListModel::PackageOperationStatus::Operating, m_debListModel->m_packageOperateStatus[m_debListModel->m_operatingPackageMd5]);
+    // asan检查 内存泄露
+    QString buffer = "11111111";
+    int length = sizeof(buffer);
+    bool isCommandExec = false;
+    m_debListModel->slotConfigReadOutput(buffer.toStdString().c_str(), length, isCommandExec);
+    EXPECT_EQ(Pkg::PackageOperationStatus::Operating,
+              m_debListModel->m_packageOperateStatus[m_debListModel->m_operatingPackageMd5]);
 }
 
-
-
 TEST_F(ut_DebListModel_test, deblistmodel_UT_onTransactionFinished)
 {
     m_debListModel->m_operatingPackageMd5 = "deb";
@@ -942,6 +961,9 @@ TEST_F(ut_DebListModel_test, deblistmodel_UT_onTransactionFinished)
     m_debListModel->m_operatingIndex = 0;
     m_debListModel->m_packageMd5.append("test");
     m_debListModel->m_packageMd5.append("test1");
+    m_debListModel->m_packagesManager->m_preparedPackages.append(QString("deb"));
+    m_debListModel->m_packagesManager->m_preparedPackages.append(QString("deb1"));
+
     Stub stub1;
     stub1.set(ADDR(QObject, sender), ut_sender);
     m_debListModel->slotTransactionFinished();
@@ -950,12 +972,96 @@ TEST_F(ut_DebListModel_test, deblistmodel_UT_onTransactionFinished)
     delete ut_sender();
 }
 
+static Transaction *g_transaction = nullptr;
+QObject *stub_UT_Transaction_Sender()
+{
+    return qobject_cast<QObject *>(g_transaction);
+}
+
+void stub_showDigitalErrWindow()
+{
+    // Do nothing.
+}
+
+QString stub_Transacton_ErrorDetails_Failed()
+{
+    // 65280 is hierarchical verfiy error code.
+    return QString("deepin hook exit code:65280");
+}
+
+TEST_F(ut_DebListModel_test, onTransactionFinished_HierarchicalVerify_Failed)
+{
+    // Enable hierarchical verify
+    stubHierachicalInvalid.set(ADDR(HierarchicalVerify, isValid), stub_DebListModel_Hierarchical_Valid);
+
+    m_debListModel->m_operatingPackageMd5 = "deb";
+    m_debListModel->m_packageFailCode.insert("deb", QApt::CommitError);
+    stub.set(ADDR(DebListModel, bumpInstallIndex), model_bumpInstallIndex);
+    stub.set(ADDR(DebListModel, showDigitalErrWindow), stub_showDigitalErrWindow);
+    stub.set(ADDR(Transaction, error), model_transaction_error);
+    stub.set(ADDR(Transaction, errorDetails), stub_Transacton_ErrorDetails_Failed);
+    m_debListModel->m_operatingIndex = 0;
+    m_debListModel->m_packageMd5.append("test");
+    m_debListModel->m_packageMd5.append("test1");
+    m_debListModel->m_packagesManager->m_preparedPackages.append(QString("deb"));
+    m_debListModel->m_packagesManager->m_preparedPackages.append(QString("deb1"));
+
+    Stub stub1;
+    g_transaction = new Transaction("1");
+    stub1.set(ADDR(QObject, sender), stub_UT_Transaction_Sender);
+    m_debListModel->m_hierarchicalVerifyError = false;
+
+    m_debListModel->slotTransactionFinished();
+    EXPECT_EQ(nullptr, m_debListModel->m_currentTransaction);
+    EXPECT_EQ(Pkg::DigitalSignatureError, m_debListModel->m_packageFailCode[m_debListModel->m_operatingPackageMd5]);
+    EXPECT_TRUE(m_debListModel->m_hierarchicalVerifyError);
+
+    delete g_transaction;
+    g_transaction = nullptr;
+}
+
+QString stub_Transacton_ErrorDetails_Pass()
+{
+    return QString("deepin hook exit code:65277");
+}
+
+TEST_F(ut_DebListModel_test, onTransactionFinished_HierarchicalVerify_Pass)
+{
+    // Enable hierarchical verify
+    stubHierachicalInvalid.set(ADDR(HierarchicalVerify, isValid), stub_DebListModel_Hierarchical_Valid);
+
+    m_debListModel->m_operatingPackageMd5 = "deb";
+    m_debListModel->m_packageFailCode.insert("deb", QApt::CommitError);
+    stub.set(ADDR(DebListModel, bumpInstallIndex), model_bumpInstallIndex);
+    stub.set(ADDR(DebListModel, showDigitalErrWindow), stub_showDigitalErrWindow);
+    stub.set(ADDR(Transaction, error), model_transaction_error);
+    stub.set(ADDR(Transaction, errorDetails), stub_Transacton_ErrorDetails_Pass);
+    m_debListModel->m_operatingIndex = 0;
+    m_debListModel->m_packageMd5.append("test");
+    m_debListModel->m_packageMd5.append("test1");
+    m_debListModel->m_packagesManager->m_preparedPackages.append(QString("deb"));
+    m_debListModel->m_packagesManager->m_preparedPackages.append(QString("deb1"));
+
+    Stub stub1;
+    g_transaction = new Transaction("1");
+    stub1.set(ADDR(QObject, sender), stub_UT_Transaction_Sender);
+    m_debListModel->m_hierarchicalVerifyError = false;
+
+    m_debListModel->slotTransactionFinished();
+    EXPECT_EQ(nullptr, m_debListModel->m_currentTransaction);
+    EXPECT_EQ(QApt::AuthError, m_debListModel->m_packageFailCode[m_debListModel->m_operatingPackageMd5]);
+    EXPECT_FALSE(m_debListModel->m_hierarchicalVerifyError);
+
+    delete g_transaction;
+    g_transaction = nullptr;
+}
+
 TEST_F(ut_DebListModel_test, deblistmodel_UT_refreshOperatingPackageStatus)
 {
     m_debListModel->m_operatingPackageMd5 = "deb";
     m_debListModel->m_packageOperateStatus.insert("deb", QApt::CommitError);
-    m_debListModel->refreshOperatingPackageStatus(DebListModel::PackageOperationStatus::Failed);
-    EXPECT_EQ(DebListModel::PackageOperationStatus::Failed, m_debListModel->m_packageOperateStatus[m_debListModel->m_operatingPackageMd5]);
+    m_debListModel->refreshOperatingPackageStatus(Pkg::PackageOperationStatus::Failed);
+    EXPECT_EQ(Pkg::PackageOperationStatus::Failed, m_debListModel->m_packageOperateStatus[m_debListModel->m_operatingPackageMd5]);
 }
 
 TEST_F(ut_DebListModel_test, deblistmodel_UT_slotDependsInstallTransactionFinished)
@@ -977,10 +1083,9 @@ TEST_F(ut_DebListModel_test, deblistmodel_UT_slotDependsInstallTransactionFinish
     delete ut_sender();
 }
 
-
 TEST_F(ut_DebListModel_test, deblistmodel_UT_showDevelopModeWindow)
 {
-    stub.set((bool (QProcess::*)(qint64 *))ADDR(QProcess, startDetached), ut_process_startDetached);
+    stub.set((bool(QProcess::*)(qint64 *))ADDR(QProcess, startDetached), ut_process_startDetached);
     m_debListModel->slotShowDevelopModeWindow();
 }
 
@@ -991,8 +1096,8 @@ TEST_F(ut_DebListModel_test, deblistmodel_UT_slotUpWrongStatusRow)
     stub.set(ADDR(DebListModel, installNextDeb), model_installNextDeb);
     stub.set(ADDR(DebListModel, bumpInstallIndex), model_installNextDeb);
     stub.set(ADDR(Transaction, error), model_transaction_error);
-    m_debListModel->m_packageOperateStatus.insert("key", DebListModel::Failed);
-    m_debListModel->m_packageOperateStatus.insert("key1", DebListModel::Success);
+    m_debListModel->m_packageOperateStatus.insert("key", Pkg::PackageOperationStatus::Failed);
+    m_debListModel->m_packageOperateStatus.insert("key1", Pkg::PackageOperationStatus::Success);
     m_debListModel->slotUpWrongStatusRow();
     EXPECT_EQ(2, m_debListModel->m_packagesManager->m_packageMd5.size());
     EXPECT_EQ(2, m_debListModel->m_packagesManager->m_preparedPackages.size());
@@ -1010,10 +1115,11 @@ TEST_F(ut_DebListModel_test, deblistmodel_UT_onTransactionOutput)
 {
     Stub stub1;
     stub1.set(ADDR(QObject, sender), ut_sender);
-    m_debListModel->m_packageOperateStatus.insert("deb", DebListModel::Prepare);
+    m_debListModel->m_packageOperateStatus.insert("deb", Pkg::PackageOperationStatus::Prepare);
     m_debListModel->m_operatingPackageMd5 = "deb";
     m_debListModel->slotTransactionOutput();
-    EXPECT_EQ(DebListModel::Operating, m_debListModel->m_packageOperateStatus[m_debListModel->m_operatingPackageMd5]);
+    EXPECT_EQ(Pkg::PackageOperationStatus::Operating,
+              m_debListModel->m_packageOperateStatus[m_debListModel->m_operatingPackageMd5]);
     delete ut_sender();
 }
 
@@ -1081,27 +1187,32 @@ TEST_F(ut_DebListModel_test, deblistmodel_UT_initInstallConnections)
     m_debListModel->initInstallConnections();
 }
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#define FILE_LINK readLink
+#else
+#define FILE_LINK symLinkTarget
+#endif
+
 TEST_F(ut_DebListModel_test, deblistmodel_UT_recheckPackagePath_readRealPathExist)
 {
-
-    stub.set((QString(QFile::*)(void)const)ADDR(QFile, readLink), stub_readLink_empty);
-    stub.set((bool(QFile::*)(void)const)ADDR(QFile, exists), stub_exists_true);
+    stub.set((QString(QFile::*)(void) const)ADDR(QFile, FILE_LINK), stub_readLink_empty);
+    stub.set((bool(QFile::*)(void) const)ADDR(QFile, exists), stub_exists_true);
 
     ASSERT_TRUE(m_debListModel->recheckPackagePath("/0"));
 }
 
 TEST_F(ut_DebListModel_test, deblistmodel_UT_recheckPackagePath_readLinkPathExist)
 {
-    stub.set((QString(QFile::*)(void)const)ADDR(QFile, readLink), stub_readLink);
-    stub.set((bool(QFile::*)(void)const)ADDR(QFile, exists), stub_exists_true);
+    stub.set((QString(QFile::*)(void) const)ADDR(QFile, FILE_LINK), stub_readLink);
+    stub.set((bool(QFile::*)(void) const)ADDR(QFile, exists), stub_exists_true);
 
     ASSERT_TRUE(m_debListModel->recheckPackagePath("/0"));
 }
 
 TEST_F(ut_DebListModel_test, deblistmodel_UT_recheckPackagePath_readLinkPathNotExist)
 {
-    stub.set((QString(QFile::*)(void)const)ADDR(QFile, readLink), stub_readLink);
-    stub.set((bool(QFile::*)(void)const)ADDR(QFile, exists), stub_exists_false);
+    stub.set((QString(QFile::*)(void) const)ADDR(QFile, FILE_LINK), stub_readLink);
+    stub.set((bool(QFile::*)(void) const)ADDR(QFile, exists), stub_exists_false);
 
     ASSERT_FALSE(m_debListModel->recheckPackagePath("/0"));
 }
@@ -1131,19 +1242,20 @@ TEST_F(ut_DebListModel_test, deblistmodel_UT_workerErrorString)
 const QList<QString> ut_preparedPackages()
 {
     QList<QString> list;
-    list << "deb" << "rpm";
+    list << "deb"
+         << "rpm";
     return list;
 }
 
 TEST_F(ut_DebListModel_test, deblistmodel_UT_digitalVerifyFailed)
 {
-//    stub.set(ADDR(DebListModel,preparedPackages),ut_preparedPackages);
-    m_debListModel->digitalVerifyFailed(DebListModel::ErrorCode::DigitalSignatureError);
+    //    stub.set(ADDR(DebListModel,preparedPackages),ut_preparedPackages);
+    m_debListModel->digitalVerifyFailed(Pkg::ErrorCode::DigitalSignatureError);
     QStringList list;
     list << "/";
     m_debListModel->slotAppendPackage(list);
     m_debListModel->m_isDevelopMode = true;
-    m_debListModel->digitalVerifyFailed(DebListModel::ErrorCode::DigitalSignatureError);
+    m_debListModel->digitalVerifyFailed(Pkg::ErrorCode::DigitalSignatureError);
     EXPECT_EQ(1, m_debListModel->m_packageFailCode.size());
 }
 
@@ -1163,9 +1275,9 @@ TEST_F(ut_DebListModel_test, deblistmodel_UT_slotNoDigitalSignature)
     QStringList list;
     list << "/";
     m_debListModel->slotAppendPackage(list);
+    m_debListModel->m_isDevelopMode = true;
     m_debListModel->slotNoDigitalSignature();
-    m_debListModel->m_operatingIndex = 0;
-    EXPECT_TRUE(m_debListModel->m_operatingIndex >= m_debListModel->m_packagesManager->m_preparedPackages.size() - 1);
+    EXPECT_EQ(1, m_debListModel->m_packageFailCode.size());
 }
 
 TEST_F(ut_DebListModel_test, deblistmodel_UT_isWorkPrepare)
