@@ -1,23 +1,6 @@
-/*
-* Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd.
-*
-* Author:     linxun <linxun@uniontech.com>
-*
-* Maintainer: linxun <linxun@uniontech.com>
-*
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "../deb-installer/view/pages/singleinstallpage.h"
 #include "../deb-installer/model/deblistmodel.h"
@@ -103,12 +86,12 @@ int stud_failedtoInt(bool *ok = nullptr)
     Q_UNUSED(ok);
     return 3;
 }
-bool stud_recheckPackagePath(QString )
+bool stud_recheckPackagePath(QString)
 {
     return true;
 }
 
-PackageDependsStatus stud_getPackageDependsStatus(const int )
+PackageDependsStatus stud_getPackageDependsStatus(const int)
 {
     return PackageDependsStatus::_break("package");
 }
@@ -116,20 +99,14 @@ PackageDependsStatus stud_getPackageDependsStatus(const int )
 class UT_SingleInstallpage : public UT_HEAD
 {
 public:
-    //添加日志
-    static void SetUpTestCase()
+    // 添加日志
+    static void SetUpTestCase() { qDebug() << "SetUpTestCase"; }
+    static void TearDownTestCase() { qDebug() << "TearDownTestCase"; }
+    void SetUp()  // TEST跑之前会执行SetUp
     {
-        qDebug() << "SetUpTestCase" << endl;
+        qDebug() << "SetUp";
     }
-    static void TearDownTestCase()
-    {
-        qDebug() << "TearDownTestCase" << endl;
-    }
-    void SetUp() //TEST跑之前会执行SetUp
-    {
-        qDebug() << "SetUp" << endl;
-    }
-    void TearDown() //TEST跑完之后会执行TearDown
+    void TearDown()  // TEST跑完之后会执行TearDown
     {
         delete page;
         delete model;
@@ -140,12 +117,12 @@ public:
 
 QVariant stu_data()
 {
-    return DebListModel::DependsOk;
+    return Pkg::DependsStatus::DependsOk;
 }
 
 QVariant stu_data1()
 {
-    return DebListModel::Success;
+    return Pkg::PackageOperationStatus::Success;
 }
 
 TEST_F(UT_SingleInstallpage, UT_SingleInstallpage_total)
@@ -160,8 +137,8 @@ TEST_F(UT_SingleInstallpage, UT_SingleInstallpage_total)
     stub.set(ADDR(DebFile, shortDescription), stud_singleshortDescription);
     stub.set(ADDR(PackagesManager, getPackageDependsStatus), stud_singlegetPackageDependsStatus);
     stub.set(ADDR(PackagesManager, packageInstallStatus), stud_singlepackageInstallStatus);
-    stub.set(ADDR(DebListModel, slotInstallPackages), stud_installPackages);
-    stub.set(ADDR(DebListModel, slotUninstallPackage), stud_singleuninstallPackage);
+    stub.set(decltype (&stud_installPackages)(&DebListModel::slotInstallPackages), stud_installPackages);
+    stub.set(decltype (&stud_singleuninstallPackage)(&DebListModel::slotUninstallPackage), stud_singleuninstallPackage);
     stub.set(ADDR(DebListModel, recheckPackagePath), stud_recheckPackagePath);
 
     model = new DebListModel();
@@ -312,8 +289,8 @@ TEST_F(UT_SingleInstallpage, UT_SingleInstallpage_onWorkFinishedFailed)
     stub.set(ADDR(DebFile, shortDescription), stud_singleshortDescription);
     stub.set(ADDR(PackagesManager, getPackageDependsStatus), stud_singlegetPackageDependsStatus);
     stub.set(ADDR(PackagesManager, packageInstallStatus), stud_singlepackageInstallStatus);
-    stub.set(ADDR(DebListModel, slotInstallPackages), stud_installPackages);
-    stub.set(ADDR(DebListModel, slotUninstallPackage), stud_singleuninstallPackage);
+    stub.set((decltype(&stud_installPackages))ADDR(DebListModel, slotInstallPackages), stud_installPackages);
+    stub.set((decltype(&stud_singleuninstallPackage))ADDR(DebListModel, slotUninstallPackage), stud_singleuninstallPackage);
     stub.set(ADDR(DebListModel, recheckPackagePath), stud_recheckPackagePath);
 
     model = new DebListModel();
@@ -348,8 +325,8 @@ TEST_F(UT_SingleInstallpage, UT_SingleInstallpage_onWorkFinishedSuccees)
     stub.set(ADDR(DebFile, shortDescription), stud_singleshortDescription);
     stub.set(ADDR(PackagesManager, getPackageDependsStatus), stud_singlegetPackageDependsStatus);
     stub.set(ADDR(PackagesManager, packageInstallStatus), stud_singlepackageInstallStatus);
-    stub.set(ADDR(DebListModel, slotInstallPackages), stud_installPackages);
-    stub.set(ADDR(DebListModel, slotUninstallPackage), stud_singleuninstallPackage);
+    stub.set((decltype(&stud_installPackages))ADDR(DebListModel, slotInstallPackages), stud_installPackages);
+    stub.set((decltype(&stud_singleuninstallPackage))ADDR(DebListModel, slotUninstallPackage), stud_singleuninstallPackage);
     stub.set(ADDR(QModelIndex, data), stu_data);
     stub.set(ADDR(DebListModel, recheckPackagePath), stud_recheckPackagePath);
     model = new DebListModel();
@@ -399,8 +376,8 @@ TEST_F(UT_SingleInstallpage, UT_SingleInstallpage_initTabOrder)
     stub.set(ADDR(DebFile, shortDescription), stud_singleshortDescription);
     stub.set(ADDR(PackagesManager, getPackageDependsStatus), stud_singlegetPackageDependsStatus);
     stub.set(ADDR(PackagesManager, packageInstallStatus), stud_singlepackageInstallStatus);
-    stub.set(ADDR(DebListModel, slotInstallPackages), stud_installPackages);
-    stub.set(ADDR(DebListModel, slotUninstallPackage), stud_singleuninstallPackage);
+    stub.set((decltype(&stud_installPackages))ADDR(DebListModel, slotInstallPackages), stud_installPackages);
+    stub.set((decltype(&stud_singleuninstallPackage))ADDR(DebListModel, slotUninstallPackage), stud_singleuninstallPackage);
     stub.set(ADDR(QModelIndex, data), stu_data);
     stub.set(ADDR(DebListModel, recheckPackagePath), stud_recheckPackagePath);
     model = new DebListModel();
@@ -438,8 +415,8 @@ TEST_F(UT_SingleInstallpage, UT_SingleInstallpage_paintEvent)
     stub.set(ADDR(DebFile, shortDescription), stud_singleshortDescription);
     stub.set(ADDR(PackagesManager, getPackageDependsStatus), stud_singlegetPackageDependsStatus);
     stub.set(ADDR(PackagesManager, packageInstallStatus), stud_singlepackageInstallStatus);
-    stub.set(ADDR(DebListModel, slotInstallPackages), stud_installPackages);
-    stub.set(ADDR(DebListModel, slotUninstallPackage), stud_singleuninstallPackage);
+    stub.set((decltype(&stud_installPackages))ADDR(DebListModel, slotInstallPackages), stud_installPackages);
+    stub.set((decltype(&stud_singleuninstallPackage))ADDR(DebListModel, slotUninstallPackage), stud_singleuninstallPackage);
     stub.set(ADDR(QModelIndex, data), stu_data);
     stub.set(ADDR(DebListModel, recheckPackagePath), stud_recheckPackagePath);
     model = new DebListModel();
@@ -464,8 +441,8 @@ TEST_F(UT_SingleInstallpage, UT_SingleInstallpage_slotDependPackages)
     stub.set(ADDR(DebFile, shortDescription), stud_singleshortDescription);
     stub.set(ADDR(PackagesManager, getPackageDependsStatus), stud_singlegetPackageDependsStatus);
     stub.set(ADDR(PackagesManager, packageInstallStatus), stud_singlepackageInstallStatus);
-    stub.set(ADDR(DebListModel, slotInstallPackages), stud_installPackages);
-    stub.set(ADDR(DebListModel, slotUninstallPackage), stud_singleuninstallPackage);
+    stub.set((decltype(&stud_installPackages))ADDR(DebListModel, slotInstallPackages), stud_installPackages);
+    stub.set((decltype(&stud_singleuninstallPackage))ADDR(DebListModel, slotUninstallPackage), stud_singleuninstallPackage);
     stub.set(ADDR(QModelIndex, data), stu_data);
     stub.set(ADDR(DebListModel, recheckPackagePath), stud_recheckPackagePath);
     model = new DebListModel();
@@ -474,13 +451,13 @@ TEST_F(UT_SingleInstallpage, UT_SingleInstallpage_slotDependPackages)
     model->m_packagesManager->m_preparedPackages.append("test1");
     page = new SingleInstallPage(model);
     usleep(100 * 1000);
-    //    QMap<QByteArray, QPair<QList<DependInfo>, QList<DependInfo>>> dependPackages;
-    DependInfo info;
+    //    QMap<QByteArray, QPair<QList<Pkg::DependInfo>, QList<Pkg::DependInfo>>> dependPackages;
+    Pkg::DependInfo info;
     info.packageName = "libopencl1";
     info.version = "1.0";
-    QList<DependInfo> list;
+    QList<Pkg::DependInfo> list;
     list.append(info);
-    QPair<QList<DependInfo>, QList<DependInfo>> pair;
+    QPair<QList<Pkg::DependInfo>, QList<Pkg::DependInfo>> pair;
     pair.first.append(list);
     pair.second.append(list);
     //    dependPackages.insert("deb", pair);
