@@ -1,3 +1,7 @@
+# SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+#
+# SPDX-License-Identifier: CC0-1.0
+
 #!/bin/bash
 builddir=build
 reportdir=build-ut
@@ -22,7 +26,7 @@ lcov -d $workdir -c -o ./coverage.info
 
 lcov --extract ./coverage.info '*/src/*' -o ./coverage.info
 
-lcov --remove ./coverage.info '*/tests/*' -o ./coverage.info
+lcov --remove ./coverage.info '*/tests/*' '*/process/*' -o ./coverage.info
 
 genhtml -o ./html ./coverage.info
 
